import 'jquery-ui/ui/position';
import { IBaseEvent, ICaptureEventConfigEntity, IDomAccessor, IDomFireEventConfigEntity, IDomParentConfigEntity, IDomPositionConfigEntity, IJQueryElement, IPresetsXYEntity, IScrollConfigEntity } from '../../definition';
export declare class DomAccessor implements IDomAccessor {
    private readonly environment;
    private readonly eventManager;
    private readonly settings;
    /**
     * @stable [24.01.2020]
     * @returns {Element}
     */
    get documentBody(): Element;
    /**
     * @stable [11.05.2020]
     * @returns {Element}
     */
    get rootElement(): Element;
    /**
     * @stable [24.01.2020]
     * @param {IDomPositionConfigEntity} cfg
     */
    setPosition(cfg: IDomPositionConfigEntity): void;
    /**
     * @stable [22.11.2020]
     * @param cfg
     */
    fireEvent(cfg: IDomFireEventConfigEntity): void;
    /**
     * @stable [22.11.2020]
     * @param cfg
     */
    dispatchEvent(cfg: IDomFireEventConfigEntity): void;
    /**
     * @stable [11.01.2020]
     * @param {Element} source
     * @returns {number}
     */
    getWidth(source: Element): number;
    /**
     * @stable [09.01.2020]
     * @param {IBaseEvent} event
     */
    cancelEvent(event: IBaseEvent): void;
    /**
     * @stable [08.01.2020]
     * @param {Partial<HTMLScriptElement>} cfg
     * @returns {Promise<HTMLScriptElement>}
     */
    createScript(cfg: Partial<HTMLScriptElement>): Promise<HTMLScriptElement>;
    /**
     * @stable [21.06.2020]
     * @param {Element} source
     * @param {string} property
     * @returns {string}
     */
    getProperty(source: Element, property: string): string;
    /**
     * @stable [23.11.2019]
     * @param {ICaptureEventConfigEntity} cfg
     * @returns {() => void}
     */
    captureEvent(cfg: ICaptureEventConfigEntity): () => void;
    /**
     * @stable [24.11.2019]
     * @param {ICaptureEventConfigEntity} cfg
     * @returns {() => void}
     */
    captureEventWithinElement(cfg: ICaptureEventConfigEntity): () => void;
    /**
     * @stable [24.01.2020]
     * @param {Element} element
     * @returns {boolean}
     */
    isElementFocused(element: Element): boolean;
    /**
     * @stable [26.10.2019]
     * @param {Element} child
     * @param {Element} parent
     * @returns {boolean}
     */
    isElementVisibleWithinParent(child: Element, parent: Element): boolean;
    /**
     * @stable [22.10.2019]
     * @param {Element} target
     * @param {string} classNames
     * @returns {boolean}
     */
    hasClasses(target: Element, ...classNames: string[]): boolean;
    /**
     * @stable [16.10.2019]
     * @param {string} selector
     * @param {Element} parent
     * @returns {Element}
     */
    findElement(selector: string, parent?: Element): Element;
    /**
     * @stable [08.10.2019]
     * @returns {boolean}
     */
    isAlreadyFocused(): boolean;
    /**
     * @stable [07.10.2019]
     * @param {string} path
     */
    redirect(path: string): void;
    /**
     * @stable [16.10.2019]
     * @param {boolean} forceReload A Boolean to indicate that the page will always reload from the server.
     *        If false or unspecified, the browser may reload the page from its HTTP cache.
     */
    reload(forceReload?: boolean): void;
    /**
     * @stable [01.10.2019]
     * @returns {Element}
     */
    addRootElement(): Element;
    /**
     * @stable [11.05.2020]
     * @param {string} clsName
     */
    addClassNamesToRootElement(...clsName: string[]): void;
    /**
     * @stable [30.09.2019]
     * @param {string} tag
     * @param {Element} parent
     * @returns {Element}
     */
    createElement<TElement extends HTMLElement = HTMLElement>(tag?: string, parent?: Element): TElement;
    /**
     * @stable [30.09.2019]
     * @param {Element} child
     * @param {Element} parent
     * @returns {Element}
     */
    addChild(child: Element, parent?: Element): Element;
    /**
     * @stable [06.02.2020]
     * @returns {string}
     */
    asImageUrl(url: string): string;
    /**
     * @stable [14.04.2019]
     * @param {Element} child
     * @param {Element} parent
     */
    removeChild(child: Element, parent?: Element): void;
    /**
     * @stable [04.04.2019]
     * @param {HTMLElement} element
     */
    enableFullScreen(element?: HTMLElement): void;
    /**
     * @stable [04.04.2019]
     * @param {HTMLElement} element
     */
    disableFullScreen(element?: HTMLElement): void;
    /**
     * @stable [31.01.2020]
     * @param {string} selector
     * @param {Element} target
     * @returns {boolean}
     */
    hasElements(selector: string, target?: Element): boolean;
    /**
     * @stable [25.01.2020]
     * @param {IDomParentConfigEntity} cfg
     * @returns {boolean}
     */
    hasParent(cfg: IDomParentConfigEntity): boolean;
    /**
     * @stable [25.01.2020]
     * @param {IDomParentConfigEntity} cfg
     * @returns {IJQueryElement}
     */
    getParents(cfg: IDomParentConfigEntity): IJQueryElement;
    /**
     * @stable [29.01.2020]
     * @param {IDomParentConfigEntity} cfg
     * @returns {TElement[]}
     */
    getParentsAsElements<TElement extends HTMLElement = HTMLElement>(cfg: IDomParentConfigEntity): TElement[];
    /**
     * @stable [13.01.2019]
     * @param {Element} element
     * @param {string} clsNames
     */
    addClassNames(element: Element, ...clsNames: string[]): void;
    /**
     * @stable [13.01.2019]
     * @param {Element} element
     * @param {string} clsNames
     */
    removeClassNames(element: Element, ...clsNames: string[]): void;
    /**
     * @stable [11.05.2020]
     * @param {string} clsNames
     */
    removeClassNamesFromRootElement(...clsNames: string[]): void;
    /**
     * @stable [18.12.2018]
     * @param {Element} el
     * @param {number} left
     */
    setScrollLeft(el: Element, left: number): void;
    /**
     * @stable [18.12.2018]
     * @param {Element} el
     * @returns {number}
     */
    getScrollLeft(el: Element): number;
    /**
     * @stable [18.12.2018]
     * @param {Element} el
     * @returns {number}
     */
    getScrollTop(el: Element): number;
    /**
     * @stable [13.12.2018]
     * @param {Element} source
     * @returns {number}
     */
    getHeight(source: Element): number;
    /**
     * @stable [13.12.2018]
     * @param {Element} source
     * @returns {IJQueryElement}
     */
    asJqEl<TJqElement extends IJQueryElement = IJQueryElement>(source: Element): TJqElement;
    /**
     * @stable [01.12.2018]
     * @param {Element} el
     * @returns {IPresetsXYEntity}
     */
    getScrollInfo(el: Element): IPresetsXYEntity;
    /**
     * @stable [01.12.2018]
     * @param {Element} source
     * @returns {number}
     */
    getContentHeight(source: Element): number;
    /**
     * @stable [08.11.2019]
     * @param {IPresetsXYEntity | Element} payload
     * @param {Element} parent
     * @param {IScrollConfigEntity} config
     */
    scrollTo(payload: IPresetsXYEntity | Element, parent?: Element, config?: IScrollConfigEntity): void;
    /**
     * @stable [01.12.2018]
     * @param {Element} el
     * @param {number} top
     */
    setScrollTop(el: Element, top: number): void;
    /**
     * @stable [09.10.2019]
     * @returns {Element}
     */
    getActiveElement(): Element;
    /**
     * @stable [17.10.2019]
     * @param {string} id
     * @returns {Element}
     */
    getElement(id: string): Element;
    /**
     * @stable [25.01.2020]
     * @param {string} selector
     * @returns {string}
     */
    asSelector(selector: string): string;
    /**
     * @stable [01.10.2019]
     * @returns {IBootstrapSettings}
     */
    private get bootstrapSettings();
    /**
     * @stable [08.10.2019]
     * @returns {Document}
     */
    private get document();
    /**
     * @stable [08.10.2019]
     * @returns {Window}
     */
    private get window();
    /**
     * @stable [31.01.2020]
     * @param {string} selector
     * @param {Element} target
     * @returns {IJQueryElement}
     */
    private findElements;
    /**
     * @stable [09.10.2019]
     * @param {Element} element
     * @returns {boolean}
     */
    private isInputElement;
}
