/// <reference types="react" />
import { ILogger } from 'ts-smart-logger';
import { BaseTextField } from '../text-field/base-text-field.component';
import { EntityIdT, AnyT } from '../../../definitions.interface';
import { MultiFieldPlugin } from '../multifield/multifield.plugin';
import { ChangeEventT, IBaseEvent, IBaseFileFieldProps, IBaseFileFieldState, IFieldInputProps, IKeyboardEvent } from '../../../definition';
export declare class BaseFileField<TProps extends IBaseFileFieldProps, TState extends IBaseFileFieldState> extends BaseTextField<TProps, TState> {
    static readonly defaultProps: IBaseFileFieldProps & Partial<import("../../../definition").IGenericComponentProps<any>>;
    protected static readonly logger: ILogger;
    protected readonly multiFieldPlugin: MultiFieldPlugin;
    private readonly dndRef;
    private readonly videoDialogRef;
    private readonly videoRef;
    /**
     * @stable [20.10.2020]
     * @param originalProps
     */
    constructor(originalProps: TProps);
    /**
     * @stable [19.10.2020]
     * @param event
     */
    onChange(event: ChangeEventT): Promise<void>;
    /**
     * @stable [20.10.2020]
     * @param event
     */
    onKeyBackspace(event: IKeyboardEvent): Promise<void>;
    /**
     * @stable [09.11.2020]
     * @param url
     */
    doAddItem(url: string): void;
    /**
     * @stable [20.10.2020]
     * @protected
     */
    protected doClearValue(): Promise<void>;
    /**
     * @stable [19.10.2020]
     * @param event
     * @protected
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [19.10.2020]
     * @param event
     * @protected
     */
    protected doCancelEvent(event: IBaseEvent): void;
    /**
     * @stable [07.11.2020]
     * @protected
     */
    protected get attachmentBodyElement(): JSX.Element;
    /**
     * @stable [02.08.2018]
     * @returns {EntityIdT[]}
     */
    protected get originalEmptyValue(): EntityIdT[];
    /**
     * @stable [05.10.2018]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [14.10.2020]
     * @protected
     */
    protected getInputElementProps(): IFieldInputProps;
    /**
     * @stable [19.10.2020]
     * @param value
     * @protected
     */
    protected decorateDisplayValue(value: AnyT): string;
    /**
     * @stable [11.05.2020]
     */
    private onVideoDialogDeactivate;
    /**
     * @stable [11.05.2020]
     */
    private onVideoDialogAccept;
    /**
     * @stable [19.10.2020]
     * @param files
     * @private
     */
    private onSelect;
    /**
     * @stable [19.10.2020]
     * @param blob
     * @private
     */
    private doAddBlob;
    /**
     * @stable [19.10.2020]
     * @param blob
     * @private
     */
    private onVideoSnapshotSelect;
    /**
     * @stable [19.10.2020]
     * @private
     */
    private openVideoDialog;
    /**
     * @stable [07.11.2020]
     * @private
     */
    private onCameraActionClick;
    /**
     * @stable [19.10.2020]
     * @private
     */
    private onAttachFileClick;
    /**
     * @stable [19.10.2020]
     * @param id
     * @private
     */
    private clearValueById;
    /**
     * @stable [28.06.2018]
     * @param {IBaseEvent} event
     */
    private downloadFile;
    /**
     * @stable [09.11.2020]
     * @private
     */
    private get isDownloadActionDisabled();
    /**
     * @stable [19.10.2020]
     * @private
     */
    private get isCameraActionDisabled();
    /**
     * @stable [19.10.2020]
     * @private
     */
    private get isNativeFileFieldUsed();
    /**
     * @stable [20.10.2020]
     * @private
     */
    private get video();
    /**
     * @stable [20.10.2020]
     * @private
     */
    private get videoDialog();
    /**
     * @stable [20.10.2020]
     * @private
     */
    private get dnd();
}
