"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultiFieldPlugin = void 0;
var util_1 = require("../../../util");
var multifield_support_1 = require("./multifield.support");
var di_1 = require("../../../di");
var MultiFieldPlugin = /** @class */ (function () {
    /**
     * @stable [14.10.2020]
     * @param field
     */
    function MultiFieldPlugin(field) {
        this.field = field;
    }
    /**
     * @stable [01.06.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onAddItem = function (item) {
        this.onChangeManually(this.toChangesPayload(this.onAdd(item)));
    };
    /**
     * @stable [01.07.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onMergeItem = function (item) {
        if (item.newEntity) {
            this.onAddItem(item);
        }
        else {
            this.onEditItem(item);
        }
    };
    /**
     * @stable [01.06.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onEditItem = function (item) {
        this.onChangeManually(this.toChangesPayload(this.onEdit(item)));
    };
    /**
     * @stable [01.06.2018]
     * @param {IMultiItemEntity} item
     */
    MultiFieldPlugin.prototype.onDeleteItem = function (item) {
        this.onChangeManually(this.toChangesPayload(this.onDelete(item)));
    };
    MultiFieldPlugin.prototype.onAdd = function (item) {
        var removeValue = this.removeValue;
        var addValue = this.addValue;
        var editArray = this.editValue;
        var removeLen = removeValue.length;
        var removeArray = removeValue.filter((function (removeItem) { return removeItem.id !== item.id; }));
        var addArray = addValue;
        if (removeArray.length === removeLen) {
            addArray = addValue.concat(multifield_support_1.fromMultiItemEntityToEntity(item));
        }
        return { addArray: addArray, removeArray: removeArray, editArray: editArray };
    };
    /**
     * @stable [11.08.2018]
     * @param {IMultiItemEntity} item
     * @returns {IMultiFieldChangesEntity}
     */
    MultiFieldPlugin.prototype.onEdit = function (item) {
        return multifield_support_1.toMultiFieldChangesEntityOnEdit(item, this.addValue, this.removeValue, this.editValue, this.originalValue);
    };
    /**
     * @stable [18.08.2018]
     * @param {IMultiItemEntity} item
     * @returns {IMultiFieldChangesEntity}
     */
    MultiFieldPlugin.prototype.onDelete = function (item) {
        return multifield_support_1.toMultiFieldChangesEntityOnDelete(item, this.addValue, this.removeValue, this.editValue, this.originalValue);
    };
    Object.defineProperty(MultiFieldPlugin.prototype, "originalValue", {
        /**
         * @stable [23.06.2018]
         * @returns {IMultiItemEntity[]}
         */
        get: function () {
            return multifield_support_1.extractMultiSourceItemEntities(this.value);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MultiFieldPlugin.prototype, "activeValue", {
        /**
         * @stable [14.10.2020]
         */
        get: function () {
            return this.fieldConverter.fromMultiFieldValueToDefinedEntities({
                source: this.originalValue,
                remove: this.removeValue,
                add: this.addValue,
                edit: this.editValue,
            });
        },
        enumerable: false,
        configurable: true
    });
    /**
     * @stable [02.06.2018]
     * @param {MultiFieldValueT} value
     * @returns {number}
     */
    MultiFieldPlugin.prototype.getActiveValueLength = function (value) {
        return util_1.asMultiFieldEntitiesLength(value);
    };
    Object.defineProperty(MultiFieldPlugin.prototype, "editValue", {
        /**
         * @stable [04.07.2018]
         * @returns {IMultiItemEntity[]}
         */
        get: function () {
            return util_1.MultiFieldUtils.multiFieldValueAsMultiItemEditEntities(this.value);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MultiFieldPlugin.prototype, "addValue", {
        /**
         * @stable [04.07.2018]
         * @returns {IEntity[]}
         */
        get: function () {
            return multifield_support_1.extractMultiAddItemEntities(this.value);
        },
        enumerable: false,
        configurable: true
    });
    /**
     * @stable [01.06.2018]
     * @param {MultiFieldValueT} payload
     */
    MultiFieldPlugin.prototype.onChangeManually = function (payload) {
        this.field.onChangeManually(payload);
    };
    /**
     * @stable [01.06.2018]
     * @param {IMultiFieldChangesEntity} result
     * @returns {MultiFieldValueT}
     */
    MultiFieldPlugin.prototype.toChangesPayload = function (result) {
        var add = result.addArray;
        var remove = result.removeArray;
        var edit = result.editArray;
        if (add.length || remove.length || edit.length) {
            return { add: add, remove: remove, edit: edit, source: this.originalValue };
        }
        else {
            return this.originalValue;
        }
    };
    Object.defineProperty(MultiFieldPlugin.prototype, "removeValue", {
        /**
         * @stable [29.08.2020]
         * @private
         */
        get: function () {
            return util_1.MultiFieldUtils.multiFieldValueAsMultiItemRemoveEntities(this.value);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MultiFieldPlugin.prototype, "value", {
        /**
         * @stable [14.10.2020]
         * @private
         */
        get: function () {
            return this.field.value;
        },
        enumerable: false,
        configurable: true
    });
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.FieldConverter),
        __metadata("design:type", Object)
    ], MultiFieldPlugin.prototype, "fieldConverter", void 0);
    return MultiFieldPlugin;
}());
exports.MultiFieldPlugin = MultiFieldPlugin;
//# sourceMappingURL=multifield.plugin.js.map