"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListActionBuilder = void 0;
var redux_effects_promise_1 = require("redux-effects-promise");
var definition_1 = require("../../definition");
var util_1 = require("../../util");
var list_interface_1 = require("./list.interface");
var ListActionBuilder = /** @class */ (function () {
    function ListActionBuilder() {
    }
    /**
     * @stable [23.09.2020]
     * @param section
     */
    ListActionBuilder.buildSortingDirectionChangeActionType = function (section) {
        return section + "." + list_interface_1.LIST_SORTING_DIRECTION_CHANGE_ACTION_TYPE;
    };
    /**
     * @stable [10.09.2020]
     * @param section
     */
    ListActionBuilder.buildMergeActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_MERGE_ACTION_TYPE;
    };
    ListActionBuilder.buildFirstPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_FIRST_PAGE_ACTION_TYPE;
    };
    ListActionBuilder.buildLastPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_LAST_PAGE_ACTION_TYPE;
    };
    ListActionBuilder.buildPreviousPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_PREVIOUS_PAGE_ACTION_TYPE;
    };
    ListActionBuilder.buildNextPageActionType = function (section) {
        return section + "." + list_interface_1.LIST_NEXT_PAGE_ACTION_TYPE;
    };
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLoadActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_LOAD_ACTION_TYPE;
    };
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildCancelLoadActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_CANCEL_LOAD_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    ListActionBuilder.buildLazyLoadActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_LAZY_LOAD_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    ListActionBuilder.buildLazyLoadDoneActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_LAZY_LOAD_DONE_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    ListActionBuilder.buildLazyLoadErrorActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_LAZY_LOAD_ERROR_ACTION_TYPE;
    };
    /**
     * @stable [15.04.2020]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildUnTouchActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + list_interface_1.LIST_UN_TOUCH_ACTION_TYPE;
    };
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildLoadDoneActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_LOAD_DONE_ACTION_TYPE;
    };
    /**
     * @stable [26.07.2020]
     * @param section
     */
    ListActionBuilder.buildLoadErrorActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_LOAD_ERROR_ACTION_TYPE;
    };
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildSelectActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_SELECT_ACTION_TYPE;
    };
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildSelectErrorActionType = function (section) {
        return redux_effects_promise_1.EffectsActionBuilder.buildErrorActionType(this.buildSelectActionType(section));
    };
    ListActionBuilder.buildInsertActionType = function (section) {
        return section + "." + list_interface_1.LIST_INSERT_ACTION_TYPE;
    };
    /**
     * @stable [17.05.2018]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildRemoveActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + list_interface_1.LIST_REMOVE_ACTION_TYPE;
    };
    ListActionBuilder.buildUpdateActionType = function (section) {
        return section + "." + list_interface_1.LIST_UPDATE_ACTION_TYPE;
    };
    /**
     * @stable [30.03.2020]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildCreateActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.LIST_CREATE_ACTION_TYPE;
    };
    /**
     * @stable [26.10.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildDeselectActionType = function (section) {
        return section + "." + list_interface_1.LIST_DESELECT_ACTION_TYPE;
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildDestroyActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + list_interface_1.LIST_DESTROY_ACTION_TYPE;
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {string}
     */
    ListActionBuilder.buildResetActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + list_interface_1.LIST_RESET_ACTION_TYPE;
    };
    /**
     * @stable [15.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildCreateAction = function (section) {
        var plainAction = this.buildCreatePlainAction(section);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [15.04.2020]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildUnTouchAction = function (section) {
        var plainAction = this.buildUnTouchPlainAction(section);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [03.06.2018]
     * @param {string} section
     * @param {ISelectedEntity} payload
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildLazyLoadAction = function (section, payload) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLazyLoadActionType(section), util_1.SectionUtils.applySection(section, payload));
    };
    /**
     * @stable [10.09.2020]
     * @param section
     */
    ListActionBuilder.buildDeselectAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDeselectActionType(section), util_1.SectionUtils.applySection(section));
    };
    ListActionBuilder.buildDeselectPlainAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDeselectActionType(section), util_1.SectionUtils.applySection(section));
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildDestroyAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDestroyActionType(section), util_1.SectionUtils.applySection(section));
    };
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildResetAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildResetActionType(section), util_1.SectionUtils.applySection(section));
    };
    /**
     * @stable [19.01.2020]
     * @param {string} section
     * @param {EntityIdT} id
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildRemoveAction = function (section, id) {
        var plainAction = this.buildRemovePlainAction(section, id);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    ListActionBuilder.buildUpdateAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildUpdateActionType(section), util_1.SectionUtils.applySection(section, data));
    };
    /**
     * @stable [11.12.2019]
     * @param section
     * @param data
     */
    ListActionBuilder.buildLoadAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLoadActionType(section), util_1.SectionUtils.applySection(section, data));
    };
    /**
     * @stable [13.05.2019]
     * @param {string} section
     * @param {IDataWrapper<AnyT> & IReduxPagedEntity} data
     * @returns {IEffectsAction}
     */
    ListActionBuilder.buildLoadDoneAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLoadDoneActionType(section), util_1.SectionUtils.applySection(section, data));
    };
    ListActionBuilder.buildNextPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildNextPageActionType(section), util_1.SectionUtils.applySection(section, data));
    };
    ListActionBuilder.buildPreviousPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildPreviousPageActionType(section), util_1.SectionUtils.applySection(section, data));
    };
    ListActionBuilder.buildFirstPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildFirstPageActionType(section), util_1.SectionUtils.applySection(section, data));
    };
    ListActionBuilder.buildLastPageAction = function (section, data) {
        return redux_effects_promise_1.EffectsAction.create(this.buildLastPageActionType(section), util_1.SectionUtils.applySection(section, data));
    };
    /**
     * @stable [23.09.2020]
     * @param section
     * @param id
     * @param changes
     */
    ListActionBuilder.buildMergeItemAction = function (section, id, changes) {
        return this.buildMergeAction(section, { id: id, changes: changes });
    };
    /**
     * @stable [10.09.2020]
     * @param section
     * @param modifyEntity
     */
    ListActionBuilder.buildMergeAction = function (section, modifyEntity) {
        var plainAction = this.buildMergePlainAction(section, modifyEntity);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [10.09.2020]
     * @param section
     * @param payload
     */
    ListActionBuilder.buildSelectAction = function (section, payload) {
        var plainAction = this.buildSelectPlainAction(section, payload);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [10.09.2020]
     * @param section
     * @param id
     */
    ListActionBuilder.buildRemovePlainAction = function (section, id) {
        return {
            type: this.buildRemoveActionType(section),
            data: util_1.SectionUtils.applySection(section, { payload: { id: id } }),
        };
    };
    /**
     * @stable [25.10.2020]
     * @param section
     */
    ListActionBuilder.buildCancelLoadAction = function (section) {
        var plainAction = this.buildCancelLoadPlainAction(section);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [10.09.2020]
     * @param section
     */
    ListActionBuilder.buildCancelLoadPlainAction = function (section) {
        return { type: this.buildCancelLoadActionType(section), data: util_1.SectionUtils.applySection(section) };
    };
    /**
     * @stable [10.09.2020]
     * @param section
     * @param data
     */
    ListActionBuilder.buildSelectPlainAction = function (section, data) {
        return { type: this.buildSelectActionType(section), data: util_1.SectionUtils.applySection(section, data) };
    };
    /**
     * @stable [10.09.2020]
     * @param section
     */
    ListActionBuilder.buildCreatePlainAction = function (section) {
        return { type: this.buildCreateActionType(section), data: util_1.SectionUtils.applySection(section) };
    };
    /**
     * @stable [10.09.2020]
     * @param section
     */
    ListActionBuilder.buildUnTouchPlainAction = function (section) {
        return { type: this.buildUnTouchActionType(section), data: util_1.SectionUtils.applySection(section) };
    };
    /**
     * @stable [23.09.2020]
     * @param section
     * @param modifyEntity
     */
    ListActionBuilder.buildMergePlainAction = function (section, modifyEntity) {
        var data = { payload: modifyEntity };
        return { type: this.buildMergeActionType(section), data: util_1.SectionUtils.applySection(section, data) };
    };
    return ListActionBuilder;
}());
exports.ListActionBuilder = ListActionBuilder;
//# sourceMappingURL=list-action.builder.js.map