"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConditionUtils = exports.ifNotTrueThanValue = exports.ifNotFalseThanValue = exports.ifNotEmptyThanValue = exports.ifNilThanValue = exports.ifNotNilThanValue = exports.orDefault = exports.orUndef = exports.orNull = exports.orEmpty = void 0;
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var util_1 = require("../util");
var calc_1 = require("./calc");
var object_1 = require("./object");
/**
 * @stable [05.04.2020]
 * @param {AnyT} condition
 * @param {string | (() => string)} result
 * @returns {string}
 */
exports.orEmpty = function (condition, result) {
    return condition ? calc_1.calc(result) : '';
};
/**
 * @stable [05.04.2020]
 * @param {AnyT} condition
 * @param {(() => TResult) | TResult} result
 * @returns {TResult}
 */
exports.orNull = function (condition, result) {
    return condition ? calc_1.calc(result) : null;
};
/**
 * @stable [05.04.2020]
 * @param {AnyT} condition
 * @param {(() => TResult) | TResult} result
 * @returns {TResult}
 */
exports.orUndef = function (condition, result) {
    return condition ? calc_1.calc(result) : definitions_interface_1.UNDEF;
};
/**
 * @deprecated
 */
function orDefault(cond, result1, result2) {
    return cond
        ? (util_1.isFn(result1) ? result1() : result1)
        : (util_1.isFn(result2) ? result2() : result2);
}
exports.orDefault = orDefault;
/**
 * @stable [10.08.2019]
 * @param {TValue} value
 * @param {(value: TValue) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNotNilThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return !R.isNil(value)
        ? callback(value)
        : (defaultValue === definitions_interface_1.UNDEF_SYMBOL ? definitions_interface_1.UNDEF : defaultValue);
};
/**
 * @stable [30.07.2019]
 * @param {TValue} value
 * @param {(value: TValue) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNilThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return R.isNil(value)
        ? callback(value)
        : (defaultValue === definitions_interface_1.UNDEF_SYMBOL ? definitions_interface_1.UNDEF : defaultValue);
};
/**
 * @stable [11.12.2020]
 * @param value
 * @param callback
 * @param defaultValue
 */
exports.ifNotEmptyThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return object_1.ObjectUtils.isObjectNotEmpty(value)
        ? callback(value)
        : (defaultValue === definitions_interface_1.UNDEF_SYMBOL ? definitions_interface_1.UNDEF : defaultValue);
};
/**
 * @stable [11.12.2020]
 * @param value
 * @param callback
 * @param defaultValue
 */
exports.ifNotFalseThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return value !== false
        ? callback(value)
        : (defaultValue === definitions_interface_1.UNDEF_SYMBOL ? definitions_interface_1.UNDEF : defaultValue);
};
/**
 * @stable [29.03.2019]
 * @param {boolean} value
 * @param {(value: boolean) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNotTrueThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return value !== true ? callback(value) : defaultValue;
};
/**
 * @stable [16.05.2020]
 */
var ConditionUtils = /** @class */ (function () {
    function ConditionUtils() {
    }
    ConditionUtils.ifNilThanValue = exports.ifNilThanValue; /* @stable [21.06.2020] */
    ConditionUtils.ifNotEmptyThanValue = exports.ifNotEmptyThanValue; /* @stable [16.05.2020] */
    ConditionUtils.ifNotFalseThanValue = exports.ifNotFalseThanValue; /* @stable [11.12.2020] */
    ConditionUtils.ifNotNilThanValue = exports.ifNotNilThanValue; /* @stable [16.05.2020] */
    ConditionUtils.orEmpty = exports.orEmpty; /* @stable [27.06.2020] */
    ConditionUtils.orNull = exports.orNull; /* @stable [18.05.2020] */
    ConditionUtils.orUndef = exports.orUndef; /* @stable [01.06.2020] */
    return ConditionUtils;
}());
exports.ConditionUtils = ConditionUtils;
//# sourceMappingURL=cond.js.map