"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidatorUtils = void 0;
var R = require("ramda");
var type_1 = require("./type");
var definition_1 = require("../definition");
var multi_field_1 = require("./multi-field");
var object_1 = require("./object");
/**
 * @stable [07.09.2020]
 * @param value
 */
var positiveNumberChecker = function (value) { return type_1.TypeUtils.isPositiveNumber(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var positiveOrNegativeNumberChecker = function (value) { return type_1.TypeUtils.isNumber(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var positiveNumberLikeChecker = function (value) { return type_1.TypeUtils.isPositiveNumberLike(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var positiveOrNegativeNumberLikeChecker = function (value) { return type_1.TypeUtils.isPositiveOrNegativeNumberLike(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var positiveOrNegativeOptionalNumberLikeChecker = function (value) {
    return type_1.TypeUtils.isPositiveOrNegativeOptionalNumberLike(value);
};
/**
 * @stable [07.09.2020]
 * @param value
 */
var positiveOptionalNumberLikeChecker = function (value) { return type_1.TypeUtils.isPositiveOptionalNumberLike(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var stringChecker = function (value) { return type_1.TypeUtils.isString(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var notEmptyStringChecker = function (value) { return type_1.TypeUtils.isNotEmptyString(value); };
/**
 * @stable [28.09.2020]
 * @param value
 */
var notEmptyObjectChecker = function (value) { return type_1.TypeUtils.isNotEmptyObject(value); };
/**
 * @stable [28.09.2020]
 * @param value
 */
var notEmptyMultiEntityChecker = function (value) {
    return object_1.ObjectUtils.isObjectNotEmpty(multi_field_1.MultiFieldUtils.multiFieldValueAsEntities(value));
};
/**
 * @stable [08.09.2020]
 */
var ValidationRules = (_a = {},
    _a[definition_1.ValidationRulesEnum.NOT_EMPTY_MULTI_ENTITY] = notEmptyMultiEntityChecker,
    _a[definition_1.ValidationRulesEnum.NOT_EMPTY_OBJECT] = notEmptyObjectChecker,
    _a[definition_1.ValidationRulesEnum.NOT_EMPTY_STRING] = notEmptyStringChecker,
    _a[definition_1.ValidationRulesEnum.POSITIVE_NUMBER] = positiveNumberChecker,
    _a[definition_1.ValidationRulesEnum.POSITIVE_NUMBER_LIKE] = positiveNumberLikeChecker,
    _a[definition_1.ValidationRulesEnum.POSITIVE_OPTIONAL_NUMBER_LIKE] = positiveOptionalNumberLikeChecker,
    _a[definition_1.ValidationRulesEnum.POSITIVE_OR_NEGATIVE_NUMBER] = positiveOrNegativeNumberChecker,
    _a[definition_1.ValidationRulesEnum.POSITIVE_OR_NEGATIVE_NUMBER_LIKE] = positiveOrNegativeNumberLikeChecker,
    _a[definition_1.ValidationRulesEnum.POSITIVE_OR_NEGATIVE_OPTIONAL_NUMBER_LIKE] = positiveOrNegativeOptionalNumberLikeChecker,
    _a[definition_1.ValidationRulesEnum.STRING] = stringChecker,
    _a);
/**
 * @stable [08.09.2020]
 * @param payloads
 * @param checkedObject
 */
var validate = function (payloads, checkedObject) {
    var data = Object.create(null);
    var valid = true;
    R.forEachObjIndexed(function (rules, fieldName) {
        var res = Object.create(null);
        data[fieldName] = res;
        [].concat(rules)
            .forEach(function (ruleId) { return valid = valid && (res[ruleId] = ValidationRules[ruleId](checkedObject[fieldName])); });
    }, payloads);
    return { valid: valid, data: data };
};
/**
 * @stable [08.09.2020]
 */
var ValidatorUtils = /** @class */ (function () {
    function ValidatorUtils() {
    }
    ValidatorUtils.validate = validate;
    return ValidatorUtils;
}());
exports.ValidatorUtils = ValidatorUtils;
//# sourceMappingURL=validator.js.map