"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WrapperUtils = exports.isPreviewUsed = exports.isOpened = exports.isDirty = exports.isUseZipCode = exports.isPlaceActionRendered = exports.isMulti = exports.isAlwaysResettable = exports.isDisabled = exports.isRangeEnabled = exports.doesErrorExist = exports.isFull = exports.isReady = void 0;
var R = require("ramda");
var cond_1 = require("./cond");
var type_1 = require("./type");
var value_1 = require("./value");
/**
 * @stable [08.06.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
var isValid = function (wrapper) {
    return R.isNil(wrapper)
        ? false
        : value_1.ValueUtils.isValueValid(wrapper.valid);
};
/**
 * @stable [22.08.2020]
 * @param wrapper
 */
var isChangeable = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.changeable !== false;
};
/**
 * @stable [22.08.2020]
 * @param wrapper
 */
var isReadOnly = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.readOnly === true;
};
/**
 * @stable [02.08.2020]
 * @param wrapper
 */
var inProgress = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.progress === true; };
/**
 * @stable [28.11.2019]
 * @param {IReadyWrapper} entity
 * @returns {boolean}
 */
exports.isReady = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.ready === true; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IFullWrapper} entity
 * @returns {boolean}
 */
exports.isFull = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.full !== false; }, false);
};
/**
 * @stable [28.11.2019]
 * @param {IErrorWrapper} entity
 * @returns {boolean}
 */
exports.doesErrorExist = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () {
        return type_1.TypeUtils.isBoolean(entity.error)
            ? entity.error === true
            : !R.isNil(entity.error);
    }, false);
};
/**
 * @stable [06.03.2020]
 * @param {IRangeEnabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isRangeEnabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.rangeEnabled === true;
};
/**
 * @stable [03.02.2020]
 * @param {IDisabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isDisabled = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.disabled === true;
};
/**
 * @stable [03.02.2020]
 * @param {ISelectedWrapper} wrapper
 * @returns {boolean}
 */
var isSelected = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.selected === true;
};
/**
 * @stable [03.02.2020]
 * @param {IExpandActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
var isExpandActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.expandActionRendered !== false;
};
/**
 * @stable [23.03.2020]
 * @param {IAlwaysResettableWrapper} wrapper
 * @returns {boolean}
 */
exports.isAlwaysResettable = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.alwaysResettable === true;
};
/**
 * @stable [24.01.2020]
 * @param {IDecoratedWrapper} wrapper
 * @returns {boolean}
 */
var isDecorated = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.decorated !== false;
};
/**
 * @stable [13.11.2019]
 * @param {IMultiWrapper} wrapper
 * @returns {boolean}
 */
exports.isMulti = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.multi === true; }, false);
};
/**
 * @stable [16.01.2020]
 * @param {ITouchedWrapper} wrapper
 * @returns {boolean}
 */
var isTouched = function (wrapper) { return R.isNil(wrapper) ? false : wrapper.touched === true; };
/**
 * @stable [08.08.2020]
 * @param wrapper
 */
var isAllowEmptyFilterValue = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.allowEmptyFilterValue !== false;
};
/**
 * @stable [26.11.2019]
 * @param {IPlaceActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isPlaceActionRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.placeActionRendered !== false;
};
/**
 * @stable [11.01.2020]
 * @param {IUseZipCodeWrapper} entity
 * @returns {boolean}
 */
exports.isUseZipCode = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.useZipCode === true; }, false);
};
/**
 * @stable [08.06.2020]
 * @param {IRefreshOnUpdateWrapper} wrapper
 * @returns {boolean}
 */
var isRefreshOnUpdateNeeded = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.refreshOnUpdate === true;
};
/**
 * @stable [01.08.2020]
 * @param entity
 */
exports.isDirty = function (entity) {
    return R.isNil(entity) ? false : entity.dirty === true;
};
/**
 * @stable [16.02.2020]
 * @param {IErrorMessageRenderedWrapper} wrapper
 * @returns {boolean}
 */
var isErrorMessageRendered = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.errorMessageRendered !== false;
};
/**
 * @stable [15.03.2020]
 * @param {IOpenedWrapper} wrapper
 * @returns {boolean}
 */
exports.isOpened = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.opened === true;
};
/**
 * @stable [16.03.2020]
 * @param {IUsePreviewWrapper} wrapper
 * @returns {boolean}
 */
exports.isPreviewUsed = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.usePreview !== false;
};
/**
 * @stable [09.09.2020]
 * @param wrapper
 */
var isNavigateBackNeeded = function (wrapper) {
    return R.isNil(wrapper) ? false : wrapper.navigateBack !== false;
};
/**
 * @stable [18.05.2020]
 */
var WrapperUtils = /** @class */ (function () {
    function WrapperUtils() {
    }
    WrapperUtils.inProgress = inProgress; /* @stable [19.05.2020] */
    WrapperUtils.isAllowEmptyFilterValue = isAllowEmptyFilterValue; /* @stable [08.08.2020] */
    WrapperUtils.isChangeable = isChangeable; /* @stable [22.08.2020] */
    WrapperUtils.isDecorated = isDecorated; /* @stable [02.06.2020] */
    WrapperUtils.isDirty = exports.isDirty; /* @stable [01.08.2020] */
    WrapperUtils.isDisabled = exports.isDisabled; /* @stable [01.06.2020] */
    WrapperUtils.isErrorMessageRendered = isErrorMessageRendered; /* @stable [18.06.2020] */
    WrapperUtils.isExpandActionRendered = isExpandActionRendered; /* @stable [16.06.2020] */
    WrapperUtils.isFull = exports.isFull; /* @stable [20.05.2020] */
    WrapperUtils.isNavigateBackNeeded = isNavigateBackNeeded; /* @stable [09.09.2020] */
    WrapperUtils.isReadOnly = isReadOnly; /* @stable [22.08.2020] */
    WrapperUtils.isRefreshOnUpdateNeeded = isRefreshOnUpdateNeeded; /* @stable [08.06.2020] */
    WrapperUtils.isSelected = isSelected; /* @stable [01.06.2020] */
    WrapperUtils.isTouched = isTouched; /* @stable [18.05.2020] */
    WrapperUtils.isValid = isValid; /* @stable [05.06.2020] */
    return WrapperUtils;
}());
exports.WrapperUtils = WrapperUtils;
//# sourceMappingURL=wrapper.js.map